<!DOCTYPE html>
<html lang="en" data-bs-theme="light">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Ramadan Tracker - Amalan</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css" rel="stylesheet">
    <style>
        :root[data-bs-theme="dark"] {
            --bs-body-bg: #212529;
            --bs-body-color: #f8f9fa;
        }

        :root[data-bs-theme="light"] {
            --bs-body-bg: #ffffff;
            --bs-body-color: #212529;
        }

        .navbar {
            box-shadow: 0 2px 4px rgba(0,0,0,.1);
        }

        .navbar-dark .navbar-nav .nav-link {
            color: rgba(255, 255, 255, 0.95);
            font-weight: 500;
            padding: 0.5rem 1rem;
            transition: all 0.3s ease;
        }
        
        .navbar-dark .navbar-nav .nav-link:hover {
            color: #ffffff;
            background-color: rgba(255, 255, 255, 0.15);
            border-radius: 4px;
        }
        
        .navbar-dark .navbar-nav .nav-link.active {
            color: #ffffff;
            background-color: rgba(255, 255, 255, 0.2);
            border-radius: 4px;
        }
        
        .navbar-dark .navbar-nav .nav-link i {
            margin-right: 5px;
        }

        .theme-icon {
            display: none;
        }

        [data-bs-theme="dark"] .theme-icon-dark {
            display: inline;
        }

        [data-bs-theme="light"] .theme-icon-light {
            display: inline;
        }
    </style>
</head>
<body>
    <?php include 'config.php'; ?>

    <nav class="navbar navbar-expand-lg navbar-dark bg-dark mb-4">
        <div class="container">
            <a class="navbar-brand" href="dashboard.php">Ramadan Tracker</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav me-auto">
                    <li class="nav-item">
                        <a class="nav-link" href="dashboard.php"><i class="fas fa-home"></i> Dashboard</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link active" href="amalan.php"><i class="fas fa-pray"></i> Amalan</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="tadarus.php"><i class="fas fa-book-open"></i> Tadarus</a>
                    </li>
                </ul>
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <button class="nav-link btn" id="theme-toggle">
                            <i class="fas fa-sun theme-icon theme-icon-light"></i>
                            <i class="fas fa-moon theme-icon theme-icon-dark"></i>
                        </button>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <div class="container">
        <h2 class="mb-4">Tracking Amalan Harian</h2>

        <?php
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            if (isset($_POST['add_amalan'])) {
                $date = $_POST['date'];
                
                // Validate Ramadan period
                $ramadan_start = strtotime('2025-03-01');
                $ramadan_end = strtotime('2025-03-30');
                $input_date = strtotime($date);
                
                if ($input_date < $ramadan_start || $input_date > $ramadan_end) {
                    echo "<div class='alert alert-danger'>Tanggal harus dalam periode Ramadan (1-30 Maret 2024)!</div>";
                } else {
                    // Check if entry already exists for this date
                    $stmt = $conn->prepare("SELECT COUNT(*) as count FROM amalan WHERE date = ?");
                    $stmt->execute([$date]);
                    $result = $stmt->fetch();
                    
                    if ($result['count'] > 0) {
                        echo "<div class='alert alert-danger'>Anda sudah menambahkan amalan untuk tanggal ini!</div>";
                    } else {
                        $fajr_prayer = isset($_POST['fajr_prayer']) ? 1 : 0;
                        $dhuhr_prayer = isset($_POST['dhuhr_prayer']) ? 1 : 0;
                        $asr_prayer = isset($_POST['asr_prayer']) ? 1 : 0;
                        $maghrib_prayer = isset($_POST['maghrib_prayer']) ? 1 : 0;
                        $isha_prayer = isset($_POST['isha_prayer']) ? 1 : 0;
                        $tarawih = isset($_POST['tarawih']) ? 1 : 0;
                        $fasting = isset($_POST['fasting']) ? 1 : 0;
                        $dhikr = isset($_POST['dhikr']) ? 1 : 0;
                        $charity = isset($_POST['charity']) ? 1 : 0;
                        $notes = $_POST['notes'];
                        
                        $stmt = $conn->prepare("INSERT INTO amalan (date, fajr_prayer, dhuhr_prayer, asr_prayer, maghrib_prayer, isha_prayer, tarawih, fasting, dhikr, charity, notes, completed) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, 0)");
                        $stmt->execute([$date, $fajr_prayer, $dhuhr_prayer, $asr_prayer, $maghrib_prayer, $isha_prayer, $tarawih, $fasting, $dhikr, $charity, $notes]);
                        echo "<div class='alert alert-success'>Amalan berhasil ditambahkan!</div>";
                    }
                }
            } elseif (isset($_POST['complete_amalan'])) {
                $amalan_id = $_POST['amalan_id'];
                $stmt = $conn->prepare("UPDATE amalan SET completed = 1 WHERE id = ?");
                $stmt->execute([$amalan_id]);
            }
        }
        ?>

        <div class="row mb-4">
            <div class="col-md-6">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Tambah Amalan Baru</h5>
                        <form method="POST">
                            <div class="mb-3">
                                <label for="date" class="form-label">Tanggal</label>
                                <?php
                                date_default_timezone_set('Asia/Jakarta');
                                $today = date('Y-m-d');
                                $ramadan_start = '2025-03-01';
                                $ramadan_end = '2025-03-30';
                                $display_date = $today;
                                
                                if (strtotime($today) < strtotime($ramadan_start)) {
                                    $display_date = $ramadan_start;
                                } elseif (strtotime($today) > strtotime($ramadan_end)) {
                                    $display_date = $ramadan_end;
                                }
                                ?>
                                <input type="date" class="form-control" id="date" name="date" value="<?php echo $display_date; ?>" readonly required>
                                <input type="date" class="form-control" id="date" name="date" value="<?php echo $display_date; ?>" readonly>
                            </div>
                            <div class="mb-3">
                                <h6>Pilih Amalan</h6>
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="fajr_prayer" id="fajr_prayer">
                                    <label class="form-check-label" for="fajr_prayer">Sholat Subuh</label>
                                </div>
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="dhuhr_prayer" id="dhuhr_prayer">
                                    <label class="form-check-label" for="dhuhr_prayer">Sholat Dzuhur</label>
                                </div>
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="asr_prayer" id="asr_prayer">
                                    <label class="form-check-label" for="asr_prayer">Sholat Ashar</label>
                                </div>
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="maghrib_prayer" id="maghrib_prayer">
                                    <label class="form-check-label" for="maghrib_prayer">Sholat Maghrib</label>
                                </div>
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="isha_prayer" id="isha_prayer">
                                    <label class="form-check-label" for="isha_prayer">Sholat Isya</label>
                                </div>
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="tarawih" id="tarawih">
                                    <label class="form-check-label" for="tarawih">Sholat Tarawih</label>
                                </div>
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="fasting" id="fasting">
                                    <label class="form-check-label" for="fasting">Puasa</label>
                                </div>
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="dhikr" id="dhikr">
                                    <label class="form-check-label" for="dhikr">Dzikir</label>
                                </div>
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="charity" id="charity">
                                    <label class="form-check-label" for="charity">Sedekah</label>
                                </div>
                            </div>
                            <div class="mb-3">
                                <label for="notes" class="form-label">Catatan Tambahan (Opsional)</label>
                                <textarea class="form-control" id="notes" name="notes" rows="2"></textarea>
                            </div>
                            <button type="submit" name="add_amalan" class="btn btn-primary">Tambah Amalan</button>
                        </form>
                    </div>
                </div>
            </div>

            <div class="col-md-6">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Daftar Amalan</h5>
                        <?php
                        $query = "SELECT * FROM amalan ORDER BY date DESC";
                        $stmt = $conn->query($query);
                        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                            echo "<div class='amalan-item'>";
                            echo "<h6>" . date('d F Y', strtotime($row['date'])) . "</h6>";
                            echo "<div class='mb-2'>";
                            if ($row['fajr_prayer']) echo "<span class='badge bg-info me-1'>Subuh</span>";
                            if ($row['dhuhr_prayer']) echo "<span class='badge bg-info me-1'>Dzuhur</span>";
                            if ($row['asr_prayer']) echo "<span class='badge bg-info me-1'>Ashar</span>";
                            if ($row['maghrib_prayer']) echo "<span class='badge bg-info me-1'>Maghrib</span>";
                            if ($row['isha_prayer']) echo "<span class='badge bg-info me-1'>Isya</span>";
                            if ($row['tarawih']) echo "<span class='badge bg-primary me-1'>Tarawih</span>";
                            if ($row['fasting']) echo "<span class='badge bg-warning me-1'>Puasa</span>";
                            if ($row['dhikr']) echo "<span class='badge bg-secondary me-1'>Dzikir</span>";
                            if ($row['charity']) echo "<span class='badge bg-success me-1'>Sedekah</span>";
                            echo "</div>";
                            if ($row['notes']) {
                                echo "<p class='text-muted'><small>{$row['notes']}</small></p>";
                            }
                            if (!$row['completed']) {
                                echo "<form method='POST' style='display: inline;'>";
                                echo "<input type='hidden' name='amalan_id' value='{$row['id']}'>";
                                echo "<button type='submit' name='complete_amalan' class='btn btn-success btn-sm'>";
                                echo "<i class='fas fa-check'></i> Selesai";
                                echo "</button>";
                                echo "</form>";
                            } else {
                                echo "<span class='badge bg-success'><i class='fas fa-check'></i> Completed</span>";
                            }
                            echo "</div>";
                        }
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Theme toggler
        document.addEventListener('DOMContentLoaded', function() {
            const themeToggle = document.getElementById('theme-toggle');
            const htmlElement = document.documentElement;

            // Check for saved theme preference
            const savedTheme = localStorage.getItem('theme') || 'light';
            htmlElement.setAttribute('data-bs-theme', savedTheme);

            themeToggle.addEventListener('click', () => {
                const currentTheme = htmlElement.getAttribute('data-bs-theme');
                const newTheme = currentTheme === 'light' ? 'dark' : 'light';
                
                htmlElement.setAttribute('data-bs-theme', newTheme);
                localStorage.setItem('theme', newTheme);
            });
        });
    </script>
</body>
</html>