<!DOCTYPE html>
<html lang="en" data-bs-theme="light">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard - Ramadan Tracker</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css" rel="stylesheet">
    <style>
        :root[data-bs-theme="dark"] {
            --bs-body-bg: #212529;
            --bs-body-color: #f8f9fa;
        }

        :root[data-bs-theme="light"] {
            --bs-body-bg: #ffffff;
            --bs-body-color: #212529;
        }

        .navbar {
            box-shadow: 0 2px 4px rgba(0,0,0,.1);
        }

        .navbar-dark .navbar-nav .nav-link {
            color: rgba(255, 255, 255, 0.95);
            font-weight: 500;
            padding: 0.5rem 1rem;
            transition: all 0.3s ease;
        }
        
        .navbar-dark .navbar-nav .nav-link:hover {
            color: #ffffff;
            background-color: rgba(255, 255, 255, 0.15);
            border-radius: 4px;
        }
        
        .navbar-dark .navbar-nav .nav-link.active {
            color: #ffffff;
            background-color: rgba(255, 255, 255, 0.2);
            border-radius: 4px;
        }
        
        .navbar-dark .navbar-nav .nav-link i {
            margin-right: 5px;
        }

        .theme-icon {
            display: none;
        }

        [data-bs-theme="dark"] .theme-icon-dark {
            display: inline;
        }

        [data-bs-theme="light"] .theme-icon-light {
            display: inline;
        }
    </style>
</head>
<body>
    <?php include 'config.php'; ?>

    <nav class="navbar navbar-expand-lg navbar-dark bg-dark mb-4">
        <div class="container">
            <a class="navbar-brand" href="dashboard.php">Ramadan Tracker</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav me-auto">
                    <li class="nav-item">
                        <a class="nav-link active" href="dashboard.php"><i class="fas fa-home"></i> Dashboard</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="amalan.php"><i class="fas fa-pray"></i> Amalan</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="tadarus.php"><i class="fas fa-book-open"></i> Tadarus</a>
                    </li>
                </ul>
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <button class="nav-link btn" id="theme-toggle">
                            <i class="fas fa-sun theme-icon theme-icon-light"></i>
                            <i class="fas fa-moon theme-icon theme-icon-dark"></i>
                        </button>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <div class="container">
        <h2 class="mb-4">Dashboard Overview</h2>
        
        <div class="row">
            <div class="col-md-4 mb-4">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title"><i class="fas fa-calendar-alt"></i> Hari Ramadan</h5>
                        <?php
                        $query = "SELECT DATEDIFF(CURDATE(), '2025-03-01') + 1 as total_days";
                        $stmt = $conn->query($query);
                        $result = $stmt->fetch(PDO::FETCH_ASSOC);
                        $ramadan_day = max(1, min(30, $result['total_days']));
                        echo "<p class='card-text'>Hari ke-" . $ramadan_day . " Ramadan</p>";
                        ?>
                    </div>
                </div>
            </div>

            <div class="col-md-4 mb-4">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title"><i class="fas fa-pray"></i> Statistik Amalan</h5>
                        <?php
                        $user_id = $_SESSION['user_id'];
                        $query = "SELECT 
                            COUNT(DISTINCT date) as total_days,
                            SUM(fajr_prayer) as fajr,
                            SUM(dhuhr_prayer) as dhuhr,
                            SUM(asr_prayer) as asr,
                            SUM(maghrib_prayer) as maghrib,
                            SUM(isha_prayer) as isha,
                            SUM(tarawih) as tarawih,
                            SUM(fasting) as fasting,
                            SUM(dhikr) as dhikr,
                            SUM(charity) as charity
                            FROM amalan 
                            WHERE user_id = ?";
                        $stmt = $conn->prepare($query);
                        $stmt->execute([$user_id]);
                        $stats = $stmt->fetch(PDO::FETCH_ASSOC);
                        
                        $total_prayers = $stats['fajr'] + $stats['dhuhr'] + $stats['asr'] + $stats['maghrib'] + $stats['isha'];
                        $max_prayers = $stats['total_days'] * 5;
                        $prayer_percentage = $max_prayers > 0 ? round(($total_prayers / $max_prayers) * 100) : 0;
                        
                        echo "<div class='mb-2'>Total Hari: " . $stats['total_days'] . " hari</div>";
                        echo "<div class='mb-2'>Shalat: " . $prayer_percentage . "% (" . $total_prayers . "/" . $max_prayers . ")</div>";
                        echo "<div class='mb-2'>Tarawih: " . $stats['tarawih'] . " hari</div>";
                        echo "<div class='mb-2'>Puasa: " . $stats['fasting'] . " hari</div>";
                        ?>
                    </div>
                </div>
            </div>

            <div class="col-md-4 mb-4">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title"><i class="fas fa-book-open"></i> Progress Tadarus</h5>
                        <?php
                        $query = "SELECT 
                            COUNT(DISTINCT date) as total_days,
                            SUM(juz_completed) as completed_juz,
                            SUM(pages_read) as total_pages
                            FROM tadarus 
                            WHERE user_id = ?";
                        $stmt = $conn->prepare($query);
                        $stmt->execute([$user_id]);
                        $tadarus = $stmt->fetch(PDO::FETCH_ASSOC);
                        
                        $juz_percentage = round(($tadarus['completed_juz'] / 30) * 100);
                        
                        echo "<div class='mb-2'>Total Hari: " . $tadarus['total_days'] . " hari</div>";
                        echo "<div class='mb-2'>Juz Selesai: " . $tadarus['completed_juz'] . "/30 (" . $juz_percentage . "%)</div>";
                        echo "<div class='mb-2'>Total Halaman: " . $tadarus['total_pages'] . " halaman</div>";
                        ?>
                    </div>
                </div>
            </div>
        </div>

        <div class="row">
            <div class="col-md-8 mb-4">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title"><i class="fas fa-chart-line"></i> Grafik Amalan Harian</h5>
                        <canvas id="amalanChart"></canvas>
                    </div>
                </div>
            </div>

            <div class="col-md-4 mb-4">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title"><i class="fas fa-chart-pie"></i> Progress Tadarus</h5>
                        <canvas id="tadarusChart"></canvas>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script>
        // Theme toggler
        document.addEventListener('DOMContentLoaded', function() {
            const themeToggle = document.getElementById('theme-toggle');
            const htmlElement = document.documentElement;

            // Check for saved theme preference
            const savedTheme = localStorage.getItem('theme') || 'light';
            htmlElement.setAttribute('data-bs-theme', savedTheme);

            themeToggle.addEventListener('click', () => {
                const currentTheme = htmlElement.getAttribute('data-bs-theme');
                const newTheme = currentTheme === 'light' ? 'dark' : 'light';
                
                htmlElement.setAttribute('data-bs-theme', newTheme);
                localStorage.setItem('theme', newTheme);
            });

            // Fetch Amalan data and create chart
            <?php
            $user_id = $_SESSION['user_id'];
            $query = "SELECT date, 
                        (fajr_prayer + dhuhr_prayer + asr_prayer + maghrib_prayer + isha_prayer) as prayers,
                        tarawih, fasting, dhikr, charity
                     FROM amalan 
                     WHERE user_id = ? 
                     ORDER BY date ASC 
                     LIMIT 30";
            $stmt = $conn->prepare($query);
            $stmt->execute([$user_id]);
            $amalan_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

            $dates = array_column($amalan_data, 'date');
            $prayers = array_column($amalan_data, 'prayers');
            $tarawih = array_column($amalan_data, 'tarawih');
            $fasting = array_column($amalan_data, 'fasting');
            ?>

            const amalanCtx = document.getElementById('amalanChart').getContext('2d');
            new Chart(amalanCtx, {
                type: 'line',
                data: {
                    labels: <?php echo json_encode($dates); ?>,
                    datasets: [{
                        label: 'Shalat',
                        data: <?php echo json_encode($prayers); ?>,
                        borderColor: '#4CAF50',
                        tension: 0.1
                    }, {
                        label: 'Tarawih',
                        data: <?php echo json_encode($tarawih); ?>,
                        borderColor: '#2196F3',
                        tension: 0.1
                    }, {
                        label: 'Puasa',
                        data: <?php echo json_encode($fasting); ?>,
                        borderColor: '#FFC107',
                        tension: 0.1
                    }]
                },
                options: {
                    responsive: true,
                    scales: {
                        y: {
                            beginAtZero: true,
                            max: 5
                        }
                    }
                }
            });

            // Fetch Tadarus data and create chart
            <?php
            $query = "SELECT SUM(juz_completed) as completed_juz FROM tadarus WHERE user_id = ?";
            $stmt = $conn->prepare($query);
            $stmt->execute([$user_id]);
            $tadarus_data = $stmt->fetch(PDO::FETCH_ASSOC);
            $completed_juz = (int)$tadarus_data['completed_juz'];
            $remaining_juz = 30 - $completed_juz;
            ?>

            const tadarusCtx = document.getElementById('tadarusChart').getContext('2d');
            new Chart(tadarusCtx, {
                type: 'doughnut',
                data: {
                    labels: ['Selesai', 'Tersisa'],
                    datasets: [{
                        data: [<?php echo $completed_juz; ?>, <?php echo $remaining_juz; ?>],
                        backgroundColor: ['#4CAF50', '#E0E0E0']
                    }]
                },
                options: {
                    responsive: true,
                    plugins: {
                        legend: {
                            position: 'bottom'
                        }
                    }
                }
            });
        });
    </script>
</body>
</html>