-- Create the database
CREATE DATABASE IF NOT EXISTS ramadan_tracker01;
USE ramadan_tracker01;

-- Create users table
CREATE TABLE users (
    id INT PRIMARY KEY AUTO_INCREMENT,
    username VARCHAR(50) NOT NULL UNIQUE,
    password VARCHAR(255) NOT NULL,
    email VARCHAR(100) NOT NULL UNIQUE,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Create amalan table
CREATE TABLE amalan (
    id INT PRIMARY KEY AUTO_INCREMENT,
    user_id INT,
    date DATE NOT NULL,
    fajr_prayer BOOLEAN DEFAULT 0,
    dhuhr_prayer BOOLEAN DEFAULT 0,
    asr_prayer BOOLEAN DEFAULT 0,
    maghrib_prayer BOOLEAN DEFAULT 0,
    isha_prayer BOOLEAN DEFAULT 0,
    tarawih BOOLEAN DEFAULT 0,
    fasting BOOLEAN DEFAULT 0,
    dhikr BOOLEAN DEFAULT 0,
    charity BOOLEAN DEFAULT 0,
    completed BOOLEAN DEFAULT 0,
    notes TEXT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE
);

-- Create tadarus table
CREATE TABLE tadarus (
    id INT PRIMARY KEY AUTO_INCREMENT,
    user_id INT,
    date DATE NOT NULL,
    juz_number INT NOT NULL,
    juz_completed BOOLEAN DEFAULT 0,
    pages_read INT DEFAULT 0,
    ayat_start INT DEFAULT 1,
    ayat_end INT DEFAULT 1,
    notes TEXT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE
);

-- Add indexes for better performance
CREATE INDEX idx_amalan_date ON amalan(date);
CREATE INDEX idx_tadarus_date ON tadarus(date);