<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Ramadan Tracker - Ranking</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary-color: #2563eb;
            --primary-hover: #1d4ed8;
            --bg-color: #f1f5f9;
            --text-color: #1e293b;
        }
        body {
            background-color: var(--bg-color);
            color: var(--text-color);
            min-height: 100vh;
            font-family: system-ui, -apple-system, sans-serif;
        }
        .navbar {
            background-color: #ffffff !important;
            box-shadow: 0 4px 6px -1px rgba(0,0,0,0.1);
            padding: 1rem 0;
        }
        .navbar-brand {
            color: var(--primary-color) !important;
            font-weight: 600;
        }
        .card {
            background-color: #ffffff;
            border: none;
            border-radius: 1rem;
            box-shadow: 0 10px 15px -3px rgba(0,0,0,0.1);
            transition: transform 0.2s ease, box-shadow 0.2s ease;
            margin-bottom: 1.5rem;
        }
        .card:hover {
            transform: translateY(-4px);
            box-shadow: 0 20px 25px -5px rgba(0,0,0,0.1);
        }
        .nav-link {
            color: var(--text-color);
            font-weight: 500;
            padding: 0.75rem 1rem;
            border-radius: 0.5rem;
            transition: all 0.2s ease;
        }
        .nav-link:hover {
            color: var(--primary-color);
            background-color: rgba(37, 99, 235, 0.1);
        }
        .nav-link.active {
            color: var(--primary-color);
            background-color: rgba(37, 99, 235, 0.1);
        }
        .nav-link i {
            margin-right: 0.5rem;
        }
        .ranking-item {
            background-color: #ffffff;
            padding: 1.5rem;
            border-radius: 1rem;
            margin-bottom: 1rem;
            box-shadow: 0 4px 6px -1px rgba(0,0,0,0.1);
            transition: transform 0.2s ease;
            display: flex;
            align-items: center;
            gap: 1.5rem;
        }
        .ranking-item:hover {
            transform: translateY(-2px);
            box-shadow: 0 10px 15px -3px rgba(0,0,0,0.1);
        }
        .rank-number {
            font-size: 1.5rem;
            font-weight: bold;
            color: var(--primary-color);
            min-width: 2.5rem;
            text-align: center;
        }
        .medal-1 {
            color: #ffd700;
            font-size: 2rem;
        }
        .medal-2 {
            color: #c0c0c0;
            font-size: 1.8rem;
        }
        .medal-3 {
            color: #cd7f32;
            font-size: 1.6rem;
        }
        @media (max-width: 768px) {
            .container {
                padding: 1rem;
            }
            .ranking-item {
                padding: 1rem;
                gap: 1rem;
            }
            .rank-number {
                font-size: 1.25rem;
                min-width: 2rem;
            }
        }
    </style>
</head>
<body>
    <?php include 'config.php'; ?>

    <nav class="navbar navbar-expand-lg navbar-dark bg-dark mb-4">
        <div class="container">
            <a class="navbar-brand" href="dashboard.php">Ramadan Tracker</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav me-auto">
                    <li class="nav-item">
                        <a class="nav-link" href="dashboard.php"><i class="fas fa-home"></i> Dashboard</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="amalan.php"><i class="fas fa-pray"></i> Amalan</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="tadarus.php"><i class="fas fa-book-open"></i> Tadarus</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link active" href="ranking.php"><i class="fas fa-trophy"></i> Ranking</a>
                    </li>
                </ul>
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <div class="container">
        <h2 class="mb-4">Ranking Ibadah</h2>

        <div class="row">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title mb-4">Top Performers</h5>
                        <?php
                        $query = "SELECT 
                                    u.username,
                                    COUNT(DISTINCT a.date) as total_days,
                                    SUM(a.fajr_prayer + a.dhuhr_prayer + a.asr_prayer + a.maghrib_prayer + a.isha_prayer + a.tarawih + a.fasting + a.dhikr + a.charity) as total_amalan,
                                    COUNT(DISTINCT t.date) as total_tadarus_days,
                                    SUM(t.juz_completed) as total_juz
                                FROM users u
                                LEFT JOIN amalan a ON u.id = a.user_id
                                LEFT JOIN tadarus t ON u.id = t.user_id
                                GROUP BY u.id, u.username
                                ORDER BY total_amalan DESC, total_juz DESC
                                LIMIT 10";
                        $stmt = $conn->query($query);
                        $rank = 1;

                        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                            $medal_class = '';
                            $medal_icon = '';
                            if ($rank === 1) {
                                $medal_class = 'medal-1';
                                $medal_icon = '<i class="fas fa-medal medal-1"></i>';
                            } elseif ($rank === 2) {
                                $medal_class = 'medal-2';
                                $medal_icon = '<i class="fas fa-medal medal-2"></i>';
                            } elseif ($rank === 3) {
                                $medal_class = 'medal-3';
                                $medal_icon = '<i class="fas fa-medal medal-3"></i>';
                            }

                            echo "<div class='ranking-item'>";
                            echo "<div class='row align-items-center'>";
                            echo "<div class='col-md-1'><span class='rank-number'>{$rank}</span> {$medal_icon}</div>";
                            echo "<div class='col-md-3'><strong>{$row['username']}</strong></div>";
                            echo "<div class='col-md-8'>";
                            echo "<div class='row'>";
                            echo "<div class='col-md-4'><i class='fas fa-calendar-check'></i> {$row['total_days']} hari</div>";
                            echo "<div class='col-md-4'><i class='fas fa-star'></i> {$row['total_amalan']} amalan</div>";
                            echo "<div class='col-md-4'><i class='fas fa-book'></i> {$row['total_juz']} juz</div>";
                            echo "</div>";
                            echo "</div>";
                            echo "</div>";
                            echo "</div>";
                            $rank++;
                        }
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>