<!DOCTYPE html>
<html lang="en" data-bs-theme="light">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tadarus - Ramadan Tracker</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css" rel="stylesheet">
    <style>
        :root[data-bs-theme="dark"] {
            --bs-body-bg: #212529;
            --bs-body-color: #f8f9fa;
        }

        :root[data-bs-theme="light"] {
            --bs-body-bg: #ffffff;
            --bs-body-color: #212529;
        }

        .navbar {
            box-shadow: 0 2px 4px rgba(0,0,0,.1);
        }

        .navbar-dark .navbar-nav .nav-link {
            color: rgba(255, 255, 255, 0.95);
            font-weight: 500;
            padding: 0.5rem 1rem;
            transition: all 0.3s ease;
        }
        
        .navbar-dark .navbar-nav .nav-link:hover {
            color: #ffffff;
            background-color: rgba(255, 255, 255, 0.15);
            border-radius: 4px;
        }
        
        .navbar-dark .navbar-nav .nav-link.active {
            color: #ffffff;
            background-color: rgba(255, 255, 255, 0.2);
            border-radius: 4px;
        }
        
        .navbar-dark .navbar-nav .nav-link i {
            margin-right: 5px;
        }

        .theme-icon {
            display: none;
        }

        [data-bs-theme="dark"] .theme-icon-dark {
            display: inline;
        }

        [data-bs-theme="light"] .theme-icon-light {
            display: inline;
        }
    </style>
</head>
<body>
    <?php include 'config.php'; ?>

    <nav class="navbar navbar-expand-lg navbar-dark bg-dark mb-4">
        <div class="container">
            <a class="navbar-brand" href="dashboard.php">Ramadan Tracker</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav me-auto">
                    <li class="nav-item">
                        <a class="nav-link" href="dashboard.php"><i class="fas fa-home"></i> Dashboard</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="amalan.php"><i class="fas fa-pray"></i> Amalan</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link active" href="tadarus.php"><i class="fas fa-book-open"></i> Tadarus</a>
                    </li>
                </ul>
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <button class="nav-link btn" id="theme-toggle">
                            <i class="fas fa-sun theme-icon theme-icon-light"></i>
                            <i class="fas fa-moon theme-icon theme-icon-dark"></i>
                        </button>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <div class="container">
        <h2 class="mb-4">Tracking Tadarus Al-Quran</h2>

        <?php
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            if (isset($_POST['add_tadarus'])) {
                $date = $_POST['date'];
                
                // Validate Ramadan period
                $ramadan_start = strtotime('2025-03-01');
                $ramadan_end = strtotime('2025-03-30');
                $input_date = strtotime($date);
                
                if ($input_date < $ramadan_start || $input_date > $ramadan_end) {
                    echo "<div class='alert alert-danger'>Tanggal harus dalam periode Ramadan (1-30 Maret 2025)!</div>";
                } else {
                    // Check if entry already exists for this date
                    $stmt = $conn->prepare("SELECT COUNT(*) as count FROM tadarus WHERE date = ?");
                    $stmt->execute([$date]);
                    $result = $stmt->fetch();
                    
                    if ($result['count'] > 0) {
                        echo "<div class='alert alert-danger'>Anda sudah menambahkan tadarus untuk tanggal ini!</div>";
                    } else {
                        $juz_number = $_POST['juz_start'];
                        $pages_read = isset($_POST['pages_read']) ? $_POST['pages_read'] : 0;
                        $notes = isset($_POST['notes']) ? $_POST['notes'] : '';
                        $ayat_start = isset($_POST['ayat_start']) && !empty($_POST['ayat_start']) ? intval($_POST['ayat_start']) : 1;
                        $ayat_end = isset($_POST['ayat_end']) && !empty($_POST['ayat_end']) ? intval($_POST['ayat_end']) : 1;

                        $stmt = $conn->prepare("INSERT INTO tadarus (date, juz_number, juz_completed, pages_read, notes, ayat_start, ayat_end) VALUES (?, ?, ?, ?, ?, ?, ?)");
                        $stmt->execute([$date, $juz_number, 1, $pages_read, $notes, $ayat_start, $ayat_end]);
                        echo "<div class='alert alert-success'>Progress tadarus berhasil ditambahkan!</div>";
                    }
                }
            }
        }
        ?>

        <div class="row mb-4">
            <div class="col-md-6">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Tambah Progress Tadarus</h5>
                        <form method="POST">
                            <div class="mb-3">
                                <label for="date" class="form-label">Tanggal</label>
                                <?php
                                $today = date('Y-m-d');
                                $ramadan_start = '2025-03-01';
                                $ramadan_end = '2025-03-30';
                                $display_date = $today;
                                
                                if (strtotime($today) < strtotime($ramadan_start)) {
                                    $display_date = $ramadan_start;
                                } elseif (strtotime($today) > strtotime($ramadan_end)) {
                                    $display_date = $ramadan_end;
                                }
                                ?>
                                <input type="date" class="form-control" id="date" name="date" value="<?php echo $display_date; ?>" readonly>
                            </div>
                            <div class="row">
                                <div class="col-md-6 mb-3">
                                    <label for="juz_start" class="form-label">Juz Awal</label>
                                    <input type="number" class="form-control" id="juz_start" name="juz_start" min="1" max="30" required>
                                </div>
                                <div class="col-md-6 mb-3">
                                    <label for="juz_end" class="form-label">Juz Akhir</label>
                                    <input type="number" class="form-control" id="juz_end" name="juz_end" min="1" max="30" required>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-6 mb-3">
                                    <label for="ayat_start" class="form-label">Ayat Awal</label>
                                    <input type="number" class="form-control" id="ayat_start" name="ayat_start" min="1" required>
                                </div>
                                <div class="col-md-6 mb-3">
                                    <label for="ayat_end" class="form-label">Ayat Akhir</label>
                                    <input type="number" class="form-control" id="ayat_end" name="ayat_end" min="1" required>
                                </div>
                            </div>
                            <div class="mb-3">
                                <label for="notes" class="form-label">Catatan</label>
                                <textarea class="form-control" id="notes" name="notes" rows="3"></textarea>
                            </div>
                            <button type="submit" name="add_tadarus" class="btn btn-primary">Tambah Progress</button>
                        </form>
                    </div>
                </div>
            </div>

            <div class="col-md-6">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Progress Al-Quran</h5>
                        <?php
                        $query = "SELECT SUM(juz_completed) as total_juz FROM tadarus";
                        $stmt = $conn->query($query);
                        $result = $stmt->fetch(PDO::FETCH_ASSOC);
                        $total_juz = $result['total_juz'] ?: 0;
                        $progress_percentage = ($total_juz / 30) * 100;
                        ?>
                        <div class="progress mb-3">
                            <div class="progress-bar bg-success" role="progressbar" style="width: <?php echo $progress_percentage; ?>%">
                                <?php echo $total_juz; ?>/30 Juz
                            </div>
                        </div>

                        <h5 class="mt-4">Riwayat Tadarus</h5>
                        <?php
                        $query = "SELECT * FROM tadarus ORDER BY date DESC";
                        $stmt = $conn->query($query);
                        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                            echo "<div class='tadarus-item'>";
                            echo "<h6>" . date('d F Y', strtotime($row['date'])) . "</h6>";
                            echo "<p>Juz " . $row['juz_number'] . " (" . ($row['juz_completed'] ? 'Completed' : 'In Progress') . ")";
                            if ($row['ayat_start'] && $row['ayat_end']) {
                                echo " - Ayat " . $row['ayat_start'] . " sampai " . $row['ayat_end'];
                            }
                            if ($row['pages_read'] > 0) {
                                echo " - " . $row['pages_read'] . " pages read";
                            }
                            echo "</p>";
                            if ($row['notes']) {
                                echo "<p class='text-muted'><small>{$row['notes']}</small></p>";
                            }
                            echo "</div>";
                        }
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Theme toggler
        document.addEventListener('DOMContentLoaded', function() {
            const themeToggle = document.getElementById('theme-toggle');
            const htmlElement = document.documentElement;

            // Check for saved theme preference
            const savedTheme = localStorage.getItem('theme') || 'light';
            htmlElement.setAttribute('data-bs-theme', savedTheme);

            themeToggle.addEventListener('click', () => {
                const currentTheme = htmlElement.getAttribute('data-bs-theme');
                const newTheme = currentTheme === 'light' ? 'dark' : 'light';
                
                htmlElement.setAttribute('data-bs-theme', newTheme);
                localStorage.setItem('theme', newTheme);
            });
        });
    </script>
</body>
</html>